[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](LICENSE)
[![Build Status](https://travis-ci.org/polyaxon/polyaxon-schemas.svg?branch=master)](https://travis-ci.org/polyaxon/polyaxon-schemas)
[![PyPI version](https://badge.fury.io/py/polyaxon-schemas.svg)](https://badge.fury.io/py/polyaxon-schemas)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/3bf5388afaa141b19e4cfc4fe58876c0)](https://www.codacy.com/app/polyaxon/polyaxon-schemas?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=polyaxon/polyaxon-schemas&amp;utm_campaign=Badge_Grade)
[![Slack](https://img.shields.io/badge/chat-on%20slack-aadada.svg?logo=slack&longCache=true)](https://join.slack.com/t/polyaxon/shared_invite/enQtMzQ0ODc2MDg1ODc0LWY2ZTdkMTNmZjBlZmRmNjQxYmYwMTBiMDZiMWJhODI2ZTk0MDU4Mjg5YzA5M2NhYzc5ZjhiMjczMDllYmQ2MDg)

# Polyaxon-schemas

Schema definitions and validation for Polyaxon.


# License

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fpolyaxon%2Fpolyaxon-schemas.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fpolyaxon%2Fpolyaxon-schemas?ref=badge_large)
